#
# spec file for package vagrant-libvirt
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global rb_build_versions %rb_default_ruby
%global rb_build_abi %rb_default_ruby_abi
%global rb_ruby_suffix %rb_default_ruby_suffix

Name:           vagrant-libvirt
Version:        0.11.2
Release:        3.1
%define mod_name vagrant-libvirt
%define mod_full_name %{mod_name}-%{version}

Requires:       libvirt
%ifarch %ix86 x86_64
Requires:       qemu-x86
%endif
# switch to %%elifarch once every platform that we care about has rpm >= 4.15
%ifarch %arm %arm64
Requires:       qemu-arm
%endif
Requires:       vagrant
# for virt-sysprep
Recommends:     guestfs-tools
BuildRequires:  vagrant

BuildRequires:  %{ruby}
BuildRequires:  ruby-macros >= 5

# for tests:
BuildRequires:  %{rubygem bundler}
BuildRequires:  %{rubygem rspec}
BuildRequires:  %{rubygem vagrant-spec}
# BuildRequire the same gems as Required
BuildRequires:  %{rubygem fog-core:2 >= 2.1}
BuildRequires:  %{rubygem fog-libvirt >= 0.3.}
BuildRequires:  %{rubygem rexml}
BuildRequires:  %{rubygem xml-simple}
BuildRequires:  %{rubygem diffy}

# s.add_development_dependency "rspec-core", ">= 3.5"
BuildRequires:  %{rubygem rspec-core >= 3.5}
# s.add_development_dependency "rspec-expectations", ">= 3.5"
BuildRequires:  %{rubygem rspec-expectations >= 3.5}
# s.add_development_dependency "rspec-mocks", ">= 3.5"
BuildRequires:  %{rubygem rspec-mocks >= 3.5}
# s.add_development_dependency 'rake'
BuildRequires:  %{rubygem rake}

# s.add_runtime_dependency 'fog-libvirt', '>= 0.6.0'
Requires:       %{rubygem fog-libvirt >= 0.6.}
# s.add_runtime_dependency 'fog-core', '~> 2'
Requires:       %{rubygem fog-core:2}
# s.add_runtime_dependency 'rexml'
Requires:       %{rubygem rexml}
# s.add_runtime_dependency 'xml-simple'
Requires:       %{rubygem xml-simple}
# s.add_runtime_dependency 'diffy'
Requires:       %{rubygem diffy}
# s.add_runtime_dependency 'nokogiri', '~> 1.6'
Requires:       %{rubygem nokogiri:1 >= 1.6 }

# required when using a non-default ruby version
BuildRequires:  %{rubygem gem2rpm}

# Prevent: have choice for rubygem(ruby:2.7.0:childprocess) >= 0
BuildRequires:  %{rubygem childprocess > 3}

BuildRequires:  fdupes
BuildRequires:  procps
BuildRequires:  kmod

URL:            https://github.com/%{name}/%{name}
Source:         https://rubygems.org/gems/%{mod_full_name}.gem
Patch:          https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1709.patch#./bundle-exec-rspec-fix-for-ruby3.2.patch

Summary:        Vagrant provider for libvirt
License:        MIT

%description
This is a Vagrant plugin that adds a Libvirt provider to Vagrant, allowing
Vagrant to control and provision machines via the Libvirt toolkit.

%package        -n %{name}-doc
Summary:        Documentation for vagrant-libvirt

%description    -n %{name}-doc
This package contains the documentation for the Libvirt provider to Vagrant.


%global vagrant_plugin_name %{name}

%prep
%gem_unpack
%autopatch -p1

%build
%gem_build

%install
%vagrant_plugin_install
%fdupes %{buildroot}%{vagrant_plugin_instdir}

%check
# Use the actual gemspec for tests
cp %{mod_full_name}/%{mod_full_name}.gemspec \
   %{buildroot}%{vagrant_plugin_instdir}/%{vagrant_plugin_name}.gemspec
pushd %{buildroot}%{vagrant_plugin_instdir}

# Create dummy Gemfile and load dependencies via the gemspec
echo "gem 'vagrant'" > Gemfile
echo "gem 'rdoc'" >> Gemfile
echo "gem 'vagrant-spec'" >> Gemfile
echo "gemspec" >> Gemfile

# Relax developement rspec dependency
sed -i '/rspec/ s/~>/>=/' %{vagrant_plugin_name}.gemspec

export GEM_PATH=%{vagrant_plugin_dir}:`ruby.%{vagrant_rb_ruby_suffix} -e "print Gem.path.join(':')"`
bundle exec rspec spec

rm %{vagrant_plugin_name}.gemspec Gemfile.lock
popd

%files
%{vagrant_plugin_instdir}
%{vagrant_plugin_cache}
%{vagrant_plugin_spec}

%doc %{mod_full_name}/README.md
%license %{mod_full_name}/LICENSE

%exclude %{vagrant_plugin_instdir}/.*
%exclude %{vagrant_plugin_instdir}/Gemfile
%exclude %{vagrant_plugin_instdir}/Rakefile
%exclude %{vagrant_plugin_instdir}/README.md
%exclude %{vagrant_plugin_instdir}/LICENSE

%files -n %{name}-doc
%doc %{vagrant_plugin_docdir}

%changelog
* Thu Mar 14 2024 Bernhard Wiedemann <bwiedemann@suse.com>
- Avoid influences from %%check on the package
* Wed Feb 22 2023 Dan Čermák <dcermak@suse.com>
- Add patch to fix test failures with Ruby 3.2
  Added patch:
  * bundle-exec-rspec-fix-for-ruby3.2.patch
* Mon Dec 12 2022 Dan Čermák <dcermak@suse.com>
- New upstream release 0.11.2
  * Handle pmsuspended resume and add state translation message by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1686
  * Include resume domain spec missed by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1689
  * Ensure iommu XML is only set for virtio nics by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1690
* Fri Dec  2 2022 Dan Čermák <dcermak@suse.com>
- New upstream release 0.11.1
  Remove patch: 0001-Mock-out-synced-folders-for-action-tests-1610.patch
  [#]# What's Changed
  * Rework release workflow by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1609
  * Bump commonmarker from 0.23.5 to 0.23.6 in /docs by @dependabot in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1607
  * Mock out synced folders for action tests by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1610
  * Use correct release branch for changelog by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1612
  * Remove need to pass machine and domain around in driver by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1579
  * Facilitate profiling of tests by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1611
  * Replace 9p synced folder :owner with :access by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1571
  * Remove remaining tabs from template by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1614
  * Bump actions/download-artifact from 2 to 3 by @dependabot in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1615
  * Bump actions/upload-artifact from 2 to 3 by @dependabot in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1616
  * Bump actions/github-script from 6.2.0 to 6.3.0 by @dependabot in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1617
  * Ensure explicit setting of inputs respected by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1619
  * Add example for use of kernel/initrd/cmdline options by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1620
  * Emit default for bootmenu to be off by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1621
  * Report graphics port after resolving by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1622
  * Update development steps by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1623
  * Select better defaults when graphics type is spice by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1625
  * Bump actions/github-script from 6.3.0 to 6.3.1 by @dependabot in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1626
  * Make code available as gem for test installs by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1629
  * Note that vagrant may select nfs or rsync as default synced_folder by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1630
  * Query host interfaces directly as libvirt may not include them by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1627
  * Ensure credentials file permissions set correctly by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1631
  * Ignore networks that cannot be used by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1628
  * Workflow to notify gem artifact available for PR by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1632
  * Adjust workflow to work for forked PRs by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1635
  * Add vcpupin support by @mark-i-m in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1007
  * Floppy support by @guss77 in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1334
  * Bump actions/github-script from 5 to 6 by @dependabot in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1637
  * Use same list_all_networks and filter by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1638
  * Disable graphics autoport attr when using spice by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1636
  * Unit context improvements by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1639
  * Use provided ssh port for machine by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1641
  * Tidy UI output on create by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1643
  * Validate provided synced_folders types for access by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1644
  * Bump JamesIves/github-pages-deploy-action from 4.4.0 to 4.4.1 by @dependabot in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1645
  * Bump nokogiri from 1.13.8 to 1.13.9 in /docs by @dependabot in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1647
  * Avoid setting cpu element on unsupported architectures by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1633
  * Update installation docs by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1650
  * Fix list networks being read-only by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1651
  * Switch to using github generated release notes by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1652
  * Publish docker image to github packages for PRs by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1646
  * Ensure reusable workflow reference correctly by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1654
  * Fix docker image workflow syntax issue by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1655
  * Ensure buildah job checks out pull request changes by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1656
  * Remove calls to set-output as now deprecated by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1657
  * Roll forward to ruby 3.1 and remove patches by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1660
  * Attempt to treat image names as text block by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1659
  * Attempt to passing multiple lines via env context by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1661
  * Replace use of secret for org name by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1662
  * Reject cpu features enabled without model by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1658
  * Tweak fedora installation instructions by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1663
  * Include distro matrix status badge from qa project by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1665
  * Use ruby 3.1.2 by default for development by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1666
  * Support running tests in parallel by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1667
  * Adding SEV support by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1664
  * Ensure default public_network :dev shown on error by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1670
  * Adding disk_address_type option. by @bdegreve in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/954
  * feat: add websocket graphics config by @Tooa in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1672
  * Add libvirt-dev to Ubuntu install by @daviddavis in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1676
  * Clear and create forwarded ports on suspend/resume by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1679
  * Ensure acceptance tests are executed  by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1680
  * Ensure dependency on ip tool is satisfied by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1681
  * Add docs to install latest development version by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1683
  * Correct destroy method call logic by @electrofelix in https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1684
* Fri Sep 23 2022 Dan Čermák <dcermak@suse.com>
- Add patch: 0001-Mock-out-synced-folders-for-action-tests-1610.patch
  (fixes test failures)
- New upstream release 0.10.8
  [#]# [0.10.8](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.10.8) (2022-09-22)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.10.7...0.10.8)
  * *Closed issues:**
- wrong upstream Vagrant install link in the documentation  [\#1601](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1601)
- Public networking cannot list my hosts devices [\#1600](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1600)
- When puppet present, it is not possible to install the plugin [\#1597](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1597)
  * *Merged pull requests:**
- Use correct url for script download in docs [\#1606](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1606) ([electrofelix](https://github.com/electrofelix))
- Update specs to check for warning not being emitted [\#1605](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1605) ([electrofelix](https://github.com/electrofelix))
- Spec fixes [\#1603](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1603) ([dcermak](https://github.com/dcermak))
- \[Dockerfile\] Fix creation of plugins.json with buildah [\#1602](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1602) ([dcermak](https://github.com/dcermak))
- fix qemu\_use\_agent to work with windows guests [\#1599](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1599) ([rgl](https://github.com/rgl))
- silence the qemu\_use\_agent warning message [\#1598](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1598) ([rgl](https://github.com/rgl))
- Handle different attribute and element ordering [\#1592](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1592) ([electrofelix](https://github.com/electrofelix))
- Add actions to be updated by dependabot [\#1586](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1586) ([electrofelix](https://github.com/electrofelix))
- Fix release workflow default branch detection [\#1585](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1585) ([electrofelix](https://github.com/electrofelix))
- Handle REXML requires for Ubuntu focal [\#1584](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1584) ([electrofelix](https://github.com/electrofelix))
* Tue Sep 13 2022 Dan Čermák <dcermak@suse.com>
- New upstream release 0.10.7
  [#]# [0.10.7](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.10.7) (2022-09-08)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.10.6...0.10.7)
  * *Closed issues:**
- Docker installation: user vagrant does not exist [\#1442](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1442)
  * *Merged pull requests:**
- Replace remaining stray references with main [\#1582](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1582) ([electrofelix](https://github.com/electrofelix))
- Make failure to apply XML domain update non fatal [\#1581](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1581) ([electrofelix](https://github.com/electrofelix))
- Remove need to explicitly set VAGRANT\_HOME before running tests [\#1580](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1580)
  ([electrofelix](https://github.com/electrofelix))
- Return early from set\_boot\_order if not needed [\#1578](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1578) ([electrofelix](https://github.com/electrofelix))
- Handle setting of graphics options avoiding XML diff [\#1577](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1577)
  ([electrofelix](https://github.com/electrofelix))
- Ensure XML diff output if not fully applied [\#1576](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1576) ([electrofelix](https://github.com/electrofelix))
- Update to more recent Ubuntu LTS [\#1575](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1575) ([electrofelix](https://github.com/electrofelix))
- Reduce nested rescues in start domain [\#1573](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1573) ([electrofelix](https://github.com/electrofelix))
- Improve handling when run using root user [\#1572](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1572) ([electrofelix](https://github.com/electrofelix))
- Correct type for workflow event [\#1570](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1570) ([electrofelix](https://github.com/electrofelix))
- Docker image bundle vagrant-libvirt with vagrant [\#1569](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1569) ([electrofelix](https://github.com/electrofelix))
- Save UI to instance to avoid passing env [\#1568](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1568) ([electrofelix](https://github.com/electrofelix))
  [#]# [0.10.6](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.10.6) (2022-08-30)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.10.5...0.10.6)
  * *Merged pull requests:**
- Switch to xml-simple for document comparison [\#1567](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1567) ([electrofelix](https://github.com/electrofelix))
  [#]# [0.10.5](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.10.5) (2022-08-29)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.10.4...0.10.5)
  * *Closed issues:**
- Error when updating domain settings: Error while creating domain: Libvirt failed to fully update the domain with the specified XML. Result differs from requested
  [\#1556](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1556)
  * *Merged pull requests:**
- Use compare-xml instead of equivalent-xml [\#1565](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1565) ([dcermak](https://github.com/dcermak))
* Mon Aug 29 2022 Dan Čermák <dcermak@suse.com>
- New upstream release 0.10.4
  [#]# [0.10.4](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.10.4) (2022-08-28)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.10.3...0.10.4)
  * *Closed issues:**
- Can't create public network interfaces [\#1561](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1561)
  * *Merged pull requests:**
- Use equivalent-xml to compare xml [\#1564](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1564) ([electrofelix](https://github.com/electrofelix))
  [#]# [0.10.3](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.10.3) (2022-08-26)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.10.2...0.10.3)
  * *Closed issues:**
- recent change to host\_devices is too strict [\#1553](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1553)
  * *Merged pull requests:**
- Use function rather than instance variable [\#1562](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1562) ([electrofelix](https://github.com/electrofelix))
- Ensure boot order is preserved unless overridden [\#1560](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1560) ([electrofelix](https://github.com/electrofelix))
- Update URL for logo display in README [\#1559](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1559) ([electrofelix](https://github.com/electrofelix))
- Ensure usernames with at symbols handled [\#1558](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1558) ([electrofelix](https://github.com/electrofelix))
* Wed Aug 24 2022 Dan Čermák <dcermak@suse.com>
- New upstream release 0.10.2
  [#]# [0.10.2](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.10.2) (2022-08-22)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.10.1...0.10.2)
  * *Closed issues:**
- Running `vagrant up` twice \(on two `Vagrantfiles`\) causes one of the VMs to loose connectivity [\#1535](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1535)
  * *Merged pull requests:**
- Allow bridges referenced by libvirt networks [\#1554](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1554) ([electrofelix](https://github.com/electrofelix))
* Thu Aug 18 2022 Dan Čermák <dcermak@suse.com>
- New upstream release 0.10.1
  [#]# [0.10.1](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.10.1) (2022-08-17)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.10.0...0.10.1)
  * *Closed issues:**
- Plugin fails to build on Arch Linux with Vagrant 2.3.0 [\#1549](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1549)
- Vagrant ignores values of "ip" in config.vm.network [\#1541](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1541)
- Failing to start without a vm.box. [\#1534](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1534)
- resolve\_disk\_settings.rb bug in 0.9.0 release [\#1519](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1519)
  * *Merged pull requests:**
- Use libvirt to query host physical devices [\#1550](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1550) ([electrofelix](https://github.com/electrofelix))
- Fix github context reference in workflow [\#1548](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1548) ([electrofelix](https://github.com/electrofelix))
  [#]# [0.10.0](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.10.0) (2022-08-16)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.9.0...0.10.0)
  * *Fixed bugs:**
- The behavior of "vagrant box add -f" is confusing with libvirt [\#1351](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1351)
  * *Closed issues:**
- net-ssh version misread version 6.2.0.rc2 is actually between 2.6.5 and 7.0.0 but,   [\#1546](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1546)
- Excessively verbose output when using virtiofs for synced folder [\#1525](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1525)
- Changing default branch to main [\#1517](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1517)
- :allow\_existing =\> "true" --\> Call to virStorageVolCreateXML failed: storage volume 'testcluster0\_shared\_disk.raw' exists already
  [\#1510](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1510)
- No box and PXE boot example from documentation fails [\#1508](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1508)
- vagrant up of existing machine fails on start\_domain.rb because 'device' is nil  [\#1490](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1490)
- vagrant up error talking to libvirt - unable to get index for interface eth0 [\#1477](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1477)
- Can't create nor destroy VM against libvirtd 8.1 [\#1471](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1471)
- Can't create VM - Call to virDomainDefineXML failed: invalid argument: could not get preferred machine
  [\#1466](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1466)
- Cant remove domain with cdrom and second storage volume  [\#1450](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1450)
- Error message given during initialization: can't activate json-2.3.0, already activated json-2.5.1 [\#1390](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1390)
  * *Merged pull requests:**
- Adjust to ensure previews load isolated code [\#1547](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1547) ([electrofelix](https://github.com/electrofelix))
- Move plugin version menu dependencies to script [\#1545](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1545) ([electrofelix](https://github.com/electrofelix))
- Adjust menu loading and styles to be more complete [\#1544](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1544) ([electrofelix](https://github.com/electrofelix))
- Load plugin versions menu always from latest [\#1543](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1543) ([electrofelix](https://github.com/electrofelix))
- Explicity set action for preview action input [\#1542](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1542) ([electrofelix](https://github.com/electrofelix))
- Switch plugin version menu to div and style by JS [\#1540](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1540) ([electrofelix](https://github.com/electrofelix))
- Make switcher JavaScript unparsed and reduce elements [\#1539](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1539)
  ([electrofelix](https://github.com/electrofelix))
- Simple maintenance improvements [\#1536](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1536) ([a1346054](https://github.com/a1346054))
- Cache requests for plugin version menu [\#1533](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1533) ([electrofelix](https://github.com/electrofelix))
- Bump github-pages from 226 to 227 in /docs [\#1531](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1531) ([dependabot[bot]](https://github.com/apps/dependabot))
- Create dependabot config [\#1530](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1530) ([electrofelix](https://github.com/electrofelix))
- Simple prepare test for 9p and virtiofs synced\_folders [\#1529](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1529)
  ([electrofelix](https://github.com/electrofelix))
- Tidy up virtiofs and 9p synced\_folder messages [\#1527](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1527) ([electrofelix](https://github.com/electrofelix))
- Support different rexml location for older vagrant [\#1526](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1526) ([nickbroon](https://github.com/nickbroon))
- Migrate documentation to github pages [\#1523](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1523) ([electrofelix](https://github.com/electrofelix))
- Ensure disk controller passed to create domain [\#1520](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1520) ([electrofelix](https://github.com/electrofelix))
- Adjust spec to avoid early setting domain volumes [\#1518](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1518) ([electrofelix](https://github.com/electrofelix))
- Correct reference to daysUntilClose [\#1516](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1516) ([electrofelix](https://github.com/electrofelix))
- Switch no-response action as probot deprecated [\#1514](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1514) ([electrofelix](https://github.com/electrofelix))
- Migrate acceptance tests to rspec [\#1513](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1513) ([electrofelix](https://github.com/electrofelix))
- Ensure box version default of 0 uses mtime [\#1512](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1512) ([electrofelix](https://github.com/electrofelix))
- Provide ruby version and gemset config for rvm [\#1511](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1511) ([electrofelix](https://github.com/electrofelix))
- Only populate domain\_name if not provided [\#1509](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1509) ([electrofelix](https://github.com/electrofelix))
- Fix allow\_existing for disks against newer versions of libvirt. [\#1507](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1507)
  ([anonym](https://github.com/anonym))
- Update after hook definition for recent vagrant [\#1506](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1506) ([electrofelix](https://github.com/electrofelix))
- Tidy up driver code [\#1505](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1505) ([electrofelix](https://github.com/electrofelix))
- Add basic tests for synced folders 9p and virtiofs [\#1504](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1504) ([electrofelix](https://github.com/electrofelix))
- Ignore dockerfile changes by default [\#1503](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1503) ([electrofelix](https://github.com/electrofelix))
- add sysinfo support [\#1500](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1500) ([nsballmann](https://github.com/nsballmann))
- Flag when source device for public network does not exist [\#1499](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1499)
  ([electrofelix](https://github.com/electrofelix))
- Avoid domain undefine on configuration update [\#1496](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1496) ([electrofelix](https://github.com/electrofelix))
- Add support for snapshots [\#1456](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1456) ([r0x0d](https://github.com/r0x0d))
* Thu Jul  7 2022 Dan Čermák <dcermak@suse.com>
- Remove patch merged upstream:
  * 0001-Replace-tabs-with-spaces-in-domain_all_settings.xml.patch
- New upstream release 0.9.0
  * *Closed issues:**
- Fedora 36 guest does not get static private network ip [\#1501](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1501)
- Unable to install `vagrant-libvirt` on Ubuntu 22.04 \(Jammy Jellyfish\) [\#1498](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1498)
- vagrant up fails to start some guests, --no-parallel succeeds [\#1495](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1495)
- Destroy fails: cannot load such file -- rexml [\#1483](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1483)
- Order of interfaces with pci passthrough [\#1475](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1475)
  * *Merged pull requests:**
- Add action to resolve disk settings [\#1502](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1502) ([electrofelix](https://github.com/electrofelix))
- Only call destroy on active networks [\#1497](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1497) ([electrofelix](https://github.com/electrofelix))
- Ensure updating loader tag supported [\#1494](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1494) ([electrofelix](https://github.com/electrofelix))
- Support different rexml location for older vagrant [\#1493](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1493) ([electrofelix](https://github.com/electrofelix))
- Switch to https from git for vagrant-spec [\#1492](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1492) ([electrofelix](https://github.com/electrofelix))
- Use instance doubles for driver where possible [\#1491](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1491) ([electrofelix](https://github.com/electrofelix))
- Replace tabs with spaces in domain\_all\_settings.xml [\#1489](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1489) ([dcermak](https://github.com/dcermak))
- Update steps in the addtional notes [\#1486](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1486) ([r0x0d](https://github.com/r0x0d))
- Fix destroying/undefining domains with NVRAM [\#1329](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1329) ([byonoy-dne](https://github.com/byonoy-dne))
* Thu May  5 2022 Dan Čermák <dcermak@suse.com>
- New upstream release 0.8.2
- Add patch:
  * 0001-Replace-tabs-with-spaces-in-domain_all_settings.xml.patch (https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1489)
  [#] Changelog
  [#]# [0.8.2](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.8.2) (2022-05-04)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.8.1...0.8.2)
  * *Closed issues:**
- Network configuration overwrites values set during provisioning since version 0.8.0 [\#1479](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1479)
- Bringing up all boxes in multi-box configuration fails with Ruby 3.1 [\#1445](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1445)
  * *Merged pull requests:**
- unrestrict fog-core version to ~\> 2 [\#1487](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1487) ([dcermak](https://github.com/dcermak))
- Update steps in the addtional notes [\#1486](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1486) ([r0x0d](https://github.com/r0x0d))
- Use require for HandleBox, SyncedFolders, WaitForCommunicator [\#1485](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1485) ([tserong](https://github.com/tserong))
- Ensure provisioner runs when performing a reload [\#1484](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1484) ([twouters](https://github.com/twouters))
- Guest PCI address options for passthrough devices [\#1481](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1481) ([jamie01](https://github.com/jamie01))
* Mon May  2 2022 Dan Čermák <dcermak@suse.com>
- Unrestrict fog-core version
* Fri Apr 22 2022 Dan Čermák <dcermak@suse.com>
- New upstream release 0.8.1
  Removed patches:
  * 0001-Remove-simplecov-from-tests.patch
  * 0002-Double-the-UDPSocket-in-cases-where-there-s-no-netwo.patch
  * 0003-Allow-the-connection.client.libversion-call-1416.patch
  [#]# [0.8.1](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.8.1) (2022-04-20)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.8.0...0.8.1)
  * *Closed issues:**
- @electrofelix All commands run successfully but `vagrant plugin install vagrant-libvirt` still output this error:
  [\#1476](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1476)
- Unable to install plugin on Ubuntu 20.04 [\#1474](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1474)
  * *Merged pull requests:**
- Ensure provisioning executed after networking [\#1480](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1480) ([electrofelix](https://github.com/electrofelix))
  [#]# [0.8.0](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.8.0) (2022-04-04)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.7.0...0.8.0)
  * *Closed issues:**
- Crash: driver.rb:138  undefined method [\#1472](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1472)
- if ssh forwarding is enabled, ssh process is left running after destroy [\#1467](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1467)
- Unable to write to '/sys/fs/cgroup/cpuset/machine/qemu-1-adminwin2016.libvirt-qemu/emulator/cpuset.cpus': Permission denied
  [\#1465](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1465)
- echo to stdout in container image breaks ansible molecule \(and possibly other applications\) [\#1463](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1463)
- Skip network deletion [\#1462](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1462)
- \[OS X\] `Vagrant failed to properly resolve required dependencies. ` for vagrant plugin install vagrant-libvirt
  [\#1461](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1461)
- unsupported configuration: virtiofs requires shared memory [\#1460](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1460)
- unable to install vagrant-libvirt on ubuntu 20.04 [\#1455](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1455)
- No slim image available on docker hub [\#1454](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1454)
- Cannot rename interface 'bridge4' to 'virbr1' on this platform: Function not implemented [\#1449](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1449)
- Create linked\_image [\#1446](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1446)
- using qemu/edk2-x86\_64-code.fd uefi firmware [\#1443](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1443)
- forwarded\_port feature with SSH tunneling does not work [\#1439](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1439)
- installation fails on RHEL 8 [\#1428](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1428)
- Docker endless loop [\#1421](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1421)
- Potential plugins collision [\#1419](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1419)
- Unit tests fail in isolated OBS workers [\#1415](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1415)
- Please support Libvirt Modular Daemons [\#1405](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1405)
- Can't install vagrant-libvirt on Fedora [\#1403](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1403)
- How to build a vagrant box of libvirt type by using ubuntu cloud image [\#1401](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1401)
- disk\_device has no effect [\#1353](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1353)
- Not able to boot a mips vm [\#1347](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1347)
- Retrieve IP Address of management interface using qemu-guest-agent commands [\#1341](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1341)
- Need assistance getting vagrant to use existing bridge intf while also assigning them static IPs [\#1339](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1339)
- How to prevent Domain Removal on provision failure? [\#1328](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1328)
- Using session rather than system, have to sudo virsh net-list --all first [\#1258](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1258)
  * *Merged pull requests:**
- Added fix for issue \#1472 [\#1473](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1473) ([ebaklund](https://github.com/ebaklund))
- Fix older bundle cloning of dependencies via git [\#1470](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1470) ([electrofelix](https://github.com/electrofelix))
- Pass ssh command for port forwarding using array [\#1469](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1469) ([electrofelix](https://github.com/electrofelix))
- From docker only output vagrant to stdout [\#1464](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1464) ([electrofelix](https://github.com/electrofelix))
- Update README.md [\#1458](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1458) ([ellcs](https://github.com/ellcs))
- Allow serials to be disabled [\#1453](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1453) ([electrofelix](https://github.com/electrofelix))
- Move autoloading to start of module [\#1451](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1451) ([electrofelix](https://github.com/electrofelix))
- Update README.md [\#1441](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1441) ([aromanos](https://github.com/aromanos))
- Fix ipv6-only routed networks [\#1440](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1440) ([rubenk](https://github.com/rubenk))
- Fix a few typos in unit test [\#1437](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1437) ([rubenk](https://github.com/rubenk))
- Fix static ipv6 ips on private networks [\#1436](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1436) ([rubenk](https://github.com/rubenk))
- Change the default amount of video ram to 16MB [\#1435](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1435) ([rubenk](https://github.com/rubenk))
- Make disabling and configuring memballoon possible [\#1434](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1434) ([rubenk](https://github.com/rubenk))
- Fix snippets about podman in README.md [\#1427](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1427) ([blame2020](https://github.com/blame2020))
- Management network keep option [\#1425](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1425) ([ssasso](https://github.com/ssasso))
- Reduce patching for distro default session use [\#1424](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1424) ([electrofelix](https://github.com/electrofelix))
- Cpu mode host-passthrough allows topology and features [\#1423](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1423)
  ([electrofelix](https://github.com/electrofelix))
- Rework prevent destroy if provider completed [\#1422](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1422) ([electrofelix](https://github.com/electrofelix))
- Ensure domain removal/halt limited to provider error [\#1420](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1420)
  ([electrofelix](https://github.com/electrofelix))
- Make simplecov a source development dependency only [\#1418](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1418)
  ([electrofelix](https://github.com/electrofelix))
- Validate partial mocks [\#1417](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1417) ([electrofelix](https://github.com/electrofelix))
- Allow the connection.client.libversion call [\#1416](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1416) ([dcermak](https://github.com/dcermak))
- Double the UDPSocket in cases where there's no network [\#1414](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1414) ([dcermak](https://github.com/dcermak))
- Make destroy network locale independent [\#1413](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1413) ([Elyfler](https://github.com/Elyfler))
- feat: Support libvirt built-in TFTP server [\#1412](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1412) ([amaczuga](https://github.com/amaczuga))
- Allow usage of public/private networks as management networks [\#1411](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1411)
  ([electrofelix](https://github.com/electrofelix))
- Remove duplicate actions for up and start [\#1410](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1410) ([electrofelix](https://github.com/electrofelix))
- Ensure sessions trigger a listing of the network devices [\#1409](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1409)
  ([electrofelix](https://github.com/electrofelix))
- Inject default qemu\_agent allowing for explicit disable [\#1408](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1408)
  ([electrofelix](https://github.com/electrofelix))
- Tidy up XML generated [\#1407](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1407) ([electrofelix](https://github.com/electrofelix))
- Remove duplicate gemspec [\#1406](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1406) ([electrofelix](https://github.com/electrofelix))
- Rework destroy domain for multiple box volumes [\#1404](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1404) ([electrofelix](https://github.com/electrofelix))
- Pin dependency to allow tests to run on older version [\#1400](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1400)
  ([electrofelix](https://github.com/electrofelix))
- Dockerfile: vagrant 2.2.19 [\#1399](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1399) ([yjftsjthsd-g](https://github.com/yjftsjthsd-g))
- Restore handling of disk\_device domain setting [\#1365](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1365) ([electrofelix](https://github.com/electrofelix))
* Tue Feb  1 2022 Dan Čermák <dcermak@suse.com>
- Switch to default ruby for Tumbleweed
* Fri Dec  3 2021 Dan Čermák <dcermak@suse.com>
- New upstream release 0.7.0
  Rebase patch:
  * 0001-Remove-simplecov-from-tests.patch
  Added patches:
  * 0002-Double-the-UDPSocket-in-cases-where-there-s-no-netwo.patch (https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1414)
  * 0003-Allow-the-connection.client.libversion-call-1416.patch (https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1416)
  [#] Changelog
  [#]# [0.7.0](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.7.0) (2021-11-08)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.6.3...0.7.0)
  * *Closed issues:**
- Network 192.168.33.10 is not available [\#1389](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1389)
- Podman example in README.md returns error [\#1373](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1373)
- VM creation fails 2nd time [\#1342](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1342)
  * *Merged pull requests:**
- Derive system URI from default URI [\#1398](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1398) ([electrofelix](https://github.com/electrofelix))
- Switch back to read-only system connection [\#1397](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1397) ([electrofelix](https://github.com/electrofelix))
- Reorder qemu agent usage for use with sessions [\#1396](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1396) ([electrofelix](https://github.com/electrofelix))
- Add gem version badge [\#1395](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1395) ([electrofelix](https://github.com/electrofelix))
- Update the source code URI [\#1394](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1394) ([electrofelix](https://github.com/electrofelix))
- Regression unit test for frozen string literal fix [\#1393](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1393) ([electrofelix](https://github.com/electrofelix))
- Fix a FrozenError in prepare\_nfs\_settings.rb [\#1392](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1392) ([rledisez](https://github.com/rledisez))
- Update issue templates [\#1391](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1391) ([electrofelix](https://github.com/electrofelix))
- Update podman instructions to mount tmp [\#1388](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1388) ([electrofelix](https://github.com/electrofelix))
- Replace Travis references in README [\#1387](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1387) ([swalkinshaw](https://github.com/swalkinshaw))
- Add options for 3d acceleration [\#1386](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1386) ([amezin](https://github.com/amezin))
- Add basic support to control serial console settings [\#1385](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1385) ([Itxaka](https://github.com/Itxaka))
- Add a :libvirt\_\_always\_destroy flag to network definitions [\#1381](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1381) ([jamie01](https://github.com/jamie01))
  [#]# [0.6.3](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.6.3) (2021-10-16)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.6.2...0.6.3)
  * *Fixed bugs:**
- The behavior of "vagrant box add -f" is confusing with libvirt [\#1351](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1351)
  * *Closed issues:**
- Wrong nameserver in /etc/resolv.conf [\#1380](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1380)
- Question: Is it it supported on windows 10? [\#1368](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1368)
  * *Merged pull requests:**
- Re-upload un-versioned boxes based on modified time [\#1382](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1382) ([electrofelix](https://github.com/electrofelix))
  [#]# [0.6.2](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.6.2) (2021-10-12)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.6.1...0.6.2)
  * *Merged pull requests:**
- Ensure ssh\_run and ssh actions match vagrant [\#1378](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1378) ([electrofelix](https://github.com/electrofelix))
  [#]# [0.6.1](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.6.1) (2021-10-11)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.6.0...0.6.1)
  * *Closed issues:**
- Running `vagrant reload && vagrant ssh -c '..'` has unexpected results with vagrant-libvirt 0.6.0 [\#1376](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1376)
- Question: Passthrough of blockdevice? [\#1350](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1350)
  * *Merged pull requests:**
- Rework shutdown domain to avoid trailing action [\#1377](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1377) ([electrofelix](https://github.com/electrofelix))
  [#]# [0.6.0](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.6.0) (2021-10-08)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.5.3...0.6.0)
  * *Closed issues:**
- Vagrant up times out after a provisioner reboots the VM [\#1366](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1366)
- Configuring provider uri per vm definition is not thread-safe [\#1358](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1358)
- support podman in addition to docker [\#1357](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1357)
- Not sure if this is a vagrant-libvirt issue but SD card is not correctly read. blk\_update\_request: I/O error. [\#1346](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1346)
- Error connecting to graphical console at virt-manager. Unable to read from monitor. [\#1340](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1340)
- ERROR warden: Error occurred: Call to virStorageVolCreateXML failed: storage volume 'xxx\_box.img' exists already [\#1338](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1338)
- MacOS can't specify accellerator as hvf [\#1336](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1336)
- bus pci.0 not found for q35 [\#1327](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1327)
- Unable to install this plugin [\#1326](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1326)
- machine\_virtual\_size has not real effect [\#1325](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1325)
- Dep ruby-libvirt broken with Vagrant 2.2.17 and Ruby \>=3.0 [\#1322](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1322)
- vagrant-libvirt wont work with centos8  [\#1317](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1317)
- Error installing vagrant-libvirt on Debian buster [\#1314](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1314)
- Creating a VM with numa fails -  Parameter -numa node,mem is not supported [\#1312](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1312)
- GPT PMBR size mismatch with second disk [\#1308](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1308)
- Export/Import Box as Original VM with `virsh dumpxml` and `virsh define`? [\#1256](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1256)
- hangs on Waiting for domain to get an IP address only on remote libvirt [\#1252](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1252)
- Error during install on Debian 10 [\#1216](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1216)
- Unable to install another plugin into  Docker based Installation [\#1198](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1198)
- Docker based Installation does not work [\#1191](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1191)
- Support frozen string literals [\#1177](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1177)
  * *Merged pull requests:**
- Add aliases for devices [\#1374](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1374) ([electrofelix](https://github.com/electrofelix))
- Handle VM not accessible during reboot [\#1367](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1367) ([electrofelix](https://github.com/electrofelix))
- Refactor create domain tests [\#1364](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1364) ([electrofelix](https://github.com/electrofelix))
- Support provider URI per machine definition [\#1363](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1363) ([electrofelix](https://github.com/electrofelix))
- Ensure sensible default USB controller model used [\#1362](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1362) ([electrofelix](https://github.com/electrofelix))
- \#1341 fix condition check on @qemu\_use\_agent [\#1361](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1361) ([abbbi](https://github.com/abbbi))
- Provide support for packaging into v2 format [\#1360](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1360) ([electrofelix](https://github.com/electrofelix))
- Document running using Podman [\#1359](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1359) ([ghost](https://github.com/ghost))
- Update to vagrant 2.2.18 for docker image [\#1354](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1354) ([electrofelix](https://github.com/electrofelix))
- Avoid blanking username if set by user [\#1352](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1352) ([electrofelix](https://github.com/electrofelix))
- Fix variable in entrypoint.sh when determining user based on Vagrantfile ownership [\#1349](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1349) ([mmguero](https://github.com/mmguero))
- Output XML elements to debug logs [\#1345](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1345) ([electrofelix](https://github.com/electrofelix))
- Support dev setting vagrant-spec version from env [\#1344](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1344) ([electrofelix](https://github.com/electrofelix))
- Retrieve IP Address of management interface using qemu-guest-agent commands \#1341 [\#1343](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1343) ([abbbi](https://github.com/abbbi))
- Improve handling of cpu model and initrd settings [\#1333](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1333) ([electrofelix](https://github.com/electrofelix))
- Fixed handling of nil volumes [\#1332](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1332) ([guss77](https://github.com/guss77))
- fix\(action\): fix typo in change domain disk\_bus [\#1331](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1331) ([gmmephisto](https://github.com/gmmephisto))
- Unrestrict rspec-\* version to \>= 3.5 to sync with vagrant [\#1330](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1330) ([dcermak](https://github.com/dcermak))
- Bump vagrant version and update README [\#1321](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1321) ([electrofelix](https://github.com/electrofelix))
- Use working directory for user/group resolution [\#1320](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1320) ([electrofelix](https://github.com/electrofelix))
- Enable frozen string across project [\#1319](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1319) ([electrofelix](https://github.com/electrofelix))
- Remove debug statement accidentally left behind [\#1318](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1318) ([electrofelix](https://github.com/electrofelix))
- Allow rspec to float on minor releases [\#1316](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1316) ([electrofelix](https://github.com/electrofelix))
- Disable removal of host keys by default [\#1315](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1315) ([electrofelix](https://github.com/electrofelix))
- Use GracefulHalt builtin action [\#1310](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1310) ([chrisroberts](https://github.com/chrisroberts))
- Basic packaging tests and restructure action [\#1307](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1307) ([electrofelix](https://github.com/electrofelix))
- Default to build and publish extendible image [\#1246](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1246) ([electrofelix](https://github.com/electrofelix))
* Wed Nov  3 2021 Dan Čermák <dcermak@suse.com>
- Fix ruby macro usage
* Wed Aug  4 2021 Dan Čermák <dcermak@suse.com>
- Unrestrict rspec-* versions
  Rebase patch:
  * 0001-Remove-simplecov-from-tests.patch
* Sat Jun 12 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.3
  * Use qemu-img json output and compute virtual size.
* Tue Jun  8 2021 Martin Hauke <mardnh@gmx.de>
- Update to version 0.5.2
  Closed issues:
  * Error occurred:
    VagrantPlugins::ProviderLibvirt::Action::HandleBoxImage::Open3
- Update to version 0.5.1
  Closed issues:
  * Value for "owner" vagrant option ends up as value for
    "access" libvirt option.
  Merged pull requests:
  * Provide Vagrantfile path in description by default.
  * Vagrant up expects machine data_dir to exist afterwards.
  * Handle extraction of keyfile from uri.
  * Handle custom port for remote libvirt.
  * add support for boot 'network' from a vagrant public_network.
- Update to version 0.5.0
  Major changes
  * Switch to use the vagrant built-in WaitForCommunicator action
    for SSH access. This may impact any action or trigger that was
    relying on WaitTillUp before attempting SSH.
  * Experiemental support for multi disk VMs using a new box format
  Fixed bugs:
  * vagrant destroy -f does not delete all metadata.
  Closed issues:
  * Error occurred:
    uninitialized constant VagrantPlugins::GuestLinux::Guest.
  * vagrant halt -f doesn't work as expected.
  * Updating vagrant-libvirt from 0.3 to 0.4.1 fails because new
    version cannot be "activated".
  * undefined method `name' for nil:NilClass (NoMethodError): Image
    remove fails if vm contains cdrom.
  * vagrant-libvirt plugin won't install on ARM64.
  * [Question] Failed to connect socket to
    '/var/run/libvirt/libvirt-sock-ro': No such file or directory.
  * Unusual disk image size created.
  * Ruby Gem rexml not builted-in.
  * vagrant destroy crashes due to nil volume in the domain.volumes
    collection.
  * libvirt__network_name doesn't work.
  * vagrant-libvirt no connection to REMOTE Provider after reboot.
  * verify the unit tests pass with rspec: 25 examples,23 failures
  Merged pull requests:
  * Make disks attribute path required check for name collisions.
  * Ensure state is correct reflected in global-status.
  * Invert forward ssh port behaviour.
  * Ensure state is fully removed for destroy.
  * Adjust forwarded ports test to include other network.
  * Enable forward ssh-port to host.
  * Exclude LIBVIRT_DEFAULT_URI from impacting tests.
  * Since Ruby 3.0 rexml needs to be required.
  * Corrections to two test testing tool.
  * Bugfix Additional Disks Storage File Ownership.
  * Retrieve disk format and virtual size directly.
  * Handle nil volumes when cd-rom attached.
  * Attempt to fix coveralls reporting.
  * Allow to use many disks in vagrant box for libvirt provider.
  * Support force halt behaviour.
  * Revert auto_config change in #1249 #1253
  * Add virtiofs Support to vagrant-libvirt.
  * Auto configuration for tunnel interfaces.
  * Add ability to define multiple private networks.
  * Add ability to manage bridge STP and delay parameters.
  * Support testing against ruby 3.0.
  * Fix forward_ports with ruby 3.0.
  * Fix interaction with reload plugin.
  * Add option to set management network MTU.
  * Add support for spinlocks hyperv feature.
* Tue Apr  6 2021 Dan Čermák <dcermak@suse.com>
- New upstream release 0.4.1
  Removed patches
  * 0001-Add-a-simple-Proc-extension-to-support-bindings.patch
  * 0002-Remove-simplecov-from-tests.patch
    (rebased as 0001-Remove-simplecov-from-tests.patch)
  Added patch:
  * 0001-Remove-simplecov-from-tests.patch
  [#] Changelog
  [#]# [0.4.1](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.4.1) (2021-04-03)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.4.0...0.4.1)
  * *Closed issues:**
- Got IP address, even though it's empty [\#1239](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1239)
- Please consider removing the contextual\_proc gem
  [\#1238](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1238)
- \[Request\]: Easy way to add plugin to docker image
  [\#1212](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1212)
- Allow declaring no inputs [\#1092](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1092)
  * *Merged pull requests:**
- Raise expected Timeout to ensure retryable retries
  [\#1241](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1241)
  ([electrofelix](https://github.com/electrofelix))
- Add a simple Proc extension to support bindings
  [\#1240](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1240) ([dcermak](https://github.com/dcermak))
- Ensure provisioner cleanup run early in destroy
  [\#1235](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1235)
  ([electrofelix](https://github.com/electrofelix))
- Replace obsolete usage of Vagrant.require\_plugin
  [\#1234](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1234)
  ([electrofelix](https://github.com/electrofelix))
* Mon Mar 29 2021 Dan Čermák <dcermak@suse.com>
- New upstream release 0.4.0
  Added patches:
  * 0001-Add-a-simple-Proc-extension-to-support-bindings.patch
  * 0002-Remove-simplecov-from-tests.patch
  [#] Changelog
  [#]# [0.4.0](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.4.0) (2021-03-21)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.3.0...0.4.0)
  * *Closed issues:**
- Fix usage/warning of not set identity file
  [\#1228](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1228)
- Vagrant stucks on "Waiting for SSH to become available" when using remote libvirt with LIBVIRT\_DEFAULT\_URI
  [\#1217](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1217)
- Windows 10 install problem : could not write value VagrantFeature to key
  [\#1215](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1215)
- vagrant plugin install vagrant-libvirt produces error: conflicting dependencies net-ssh \(\>= 2.6.5\) and
  net-ssh \(= 6.2.0.rc1\) [\#1210](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1210)
- Error while creating domain: Error saving the server: Call to virDomainDefineXML failed: invalid argument:
  could not find capabilities for domaintype=kvm
  [\#1208](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1208)
- libk5crypto.so.3: undefined symbol: EVP\_KDF\_ctrl, version OPENSSL\_1\_1\_1b
  [\#1203](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1203)
- Vagrant not sharing project directory to /vagrant in case of certain boxes
  [\#1201](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1201)
- Vagrant up not working on Fedora 33 [\#1185](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1185)
- vagrant-libvirt is missing rsync in the image
  [\#1183](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1183)
- Version tagging not working when using the release zip
  [\#1181](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1181)
- Network Interface Order? [\#1180](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1180)
- Error when updating domain settings: undefined method `strip' for nil:NilClass
  [\#1176](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1176)
- Support OpenRC [\#1175](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1175)
- What is the default host IP? [\#1174](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1174)
- ability to choose default boot interface when multiple interfaces
  [\#1173](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1173)
- NIC duplicates created when using vagrant-libvirt
  [\#1165](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1165)
- Remote libvirt host. Waiting for domain to get an IP address
  [\#1160](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1160)
- Cannot reate  [\#1147](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1147)
- vagrant cannot create vm [\#1133](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1133)
- Installation inside Docker [\#1128](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1128)
- Centos 8 /lib64/libk5crypto.so.3: undefined symbol: EVP\_KDF\_ctrl, version OPENSSL\_1\_1\_1b
  [\#1127](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1127)
- New box created using create\_box.sh - gets stuck at "Waiting for SSH to become available..."
  [\#1116](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1116)
- Does not install on Fedora 32 [\#1105](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1105)
-  default: Waiting for domain to get an IP address
  [\#1084](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1084)
- Plugin does not install on Fedora 31 [\#1082](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1082)
- Add support for virt-sysprep options [\#1077](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1077)
- add support for disk I/O options [\#998](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/998)
- storage :file fail with QEMU session [\#986](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/986)
- Install vargant-libvirt plugin issue [\#982](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/982)
- Installation on OpenSUSE Leap 15.0 fails [\#968](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/968)
- Add support for tpm\_version [\#965](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/965)
  * *Merged pull requests:**
- Ensure multi machine IP retrieval works [\#1232](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1232)
  ([electrofelix](https://github.com/electrofelix))
- Extract finalizing from the uri to a separate method
  [\#1231](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1231)
  ([electrofelix](https://github.com/electrofelix))
- Improve id\_ssh\_key\_file finalizing [\#1230](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1230)
  ([electrofelix](https://github.com/electrofelix))
- Bugfix some stray machine args after tidy up
  [\#1227](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1227)
  ([electrofelix](https://github.com/electrofelix))
- Move proxy\_command to config and support templating
  [\#1226](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1226)
  ([electrofelix](https://github.com/electrofelix))
- auto enable ssh connection [\#1225](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1225)
  ([electrofelix](https://github.com/electrofelix))
- Only set ssh connection params if transport is ssh
  [\#1224](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1224)
  ([electrofelix](https://github.com/electrofelix))
- Make LIBVIRT\_DEFAULT\_URI a fackball mechanism
  [\#1223](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1223)
  ([electrofelix](https://github.com/electrofelix))
- Use OpenSSH functionality instead of netcat for proxy\_command
  [\#1222](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1222)
  ([electrofelix](https://github.com/electrofelix))
- Remove flag-name due to behaviour mismatch
  [\#1220](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1220)
  ([electrofelix](https://github.com/electrofelix))
- Refactor uri config tests [\#1219](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1219)
  ([electrofelix](https://github.com/electrofelix))
- Fix remote libvirt functionality through LIBVIRT\_DEFAULT\_URI
  [\#1218](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1218)
  ([ElArtista](https://github.com/ElArtista))
- Added notes on how to download source RPMS for CentOS 8 stream
  [\#1213](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1213) ([nmaludy](https://github.com/nmaludy))
- Ensure github actions run on merge to main branch
  [\#1207](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1207)
  ([electrofelix](https://github.com/electrofelix))
- Switch from travis to github actions for unit tests
  [\#1206](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1206)
  ([electrofelix](https://github.com/electrofelix))
- Consolidate ip address retreival to single method
  [\#1199](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1199)
  ([electrofelix](https://github.com/electrofelix))
- Use correct shell variable for options pass-thru
  [\#1197](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1197)
  ([electrofelix](https://github.com/electrofelix))
- Make a virtual machine disk sparse with `virt-sparsify`
  [\#1195](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1195) ([hswong3i](https://github.com/hswong3i))
- Improving Docker based Installation [\#1194](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1194)
  ([pgillich](https://github.com/pgillich))
- Update TOC with recent additions [\#1189](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1189)
  ([electrofelix](https://github.com/electrofelix))
- Include recent vagrant release in tests [\#1188](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1188)
  ([electrofelix](https://github.com/electrofelix))
- Support building from git-archive tarballs
  [\#1187](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1187)
  ([electrofelix](https://github.com/electrofelix))
- Include rsync to support syncing folders [\#1186](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1186)
  ([electrofelix](https://github.com/electrofelix))
- Fix Broken `/etc/machine-id` by `vagrant package` due to virt-sysprep's `customize` operation
  [\#1184](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1184) ([hswong3i](https://github.com/hswong3i))
- Exclude spec helpers from coverage [\#1179](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1179)
  ([electrofelix](https://github.com/electrofelix))
- Reduce start domain unnecessary domain redefines
  [\#1178](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1178)
  ([electrofelix](https://github.com/electrofelix))
- Provide uid/gid for additional volumes qemu:///session
  [\#1170](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1170)
  ([electrofelix](https://github.com/electrofelix))
- Add doc on ssh key replacement if repackaging
  [\#1169](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1169)
  ([electrofelix](https://github.com/electrofelix))
- Add ability to use emulated tpm [\#1166](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1166)
  ([JTarasovic](https://github.com/JTarasovic))
- Use Github actions for integration tests against Vagrant-libvirt
  [\#1091](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1091) ([abbbi](https://github.com/abbbi))
- Add support for configuring memballoon-related settings
  [\#1083](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1083) ([erhudy](https://github.com/erhudy))
- Add support for clock setup [\#1047](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1047)
  ([zzambers](https://github.com/zzambers))
- Add disk driver options with minor refactor
  [\#1000](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1000)
  ([davidscaife](https://github.com/davidscaife))
* Fri Nov 20 2020 Dan Čermák <dcermak@suse.com>
- New upstream release 0.3.0
  [#] Changelog
  [#]# [0.3.0](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.3.0) (2020-11-16)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.2.1...0.3.0)
  * *Closed issues:**
- Support parameters for openvswitch network configuration [\#1155](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1155)
- Correctly support the new --no-tty option [\#1106](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1106)
  * *Merged pull requests:**
- Update issue template to request log be attached [\#1168](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1168) ([electrofelix](https://github.com/electrofelix))
- Rudimentary start domain action spec [\#1167](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1167) ([electrofelix](https://github.com/electrofelix))
- Use github cache for docker layers [\#1164](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1164) ([electrofelix](https://github.com/electrofelix))
- Gemfile: update branch-name of 'vagrant-spec' [\#1163](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1163) ([kfix](https://github.com/kfix))
- Ensure docker image build has history for version resolving [\#1162](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1162) ([electrofelix](https://github.com/electrofelix))
- Tag version from git tag [\#1161](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1161) ([electrofelix](https://github.com/electrofelix))
- Try using bundler cache for faster CI [\#1159](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1159) ([electrofelix](https://github.com/electrofelix))
- Add rudimentary create domain spec test [\#1158](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1158) ([electrofelix](https://github.com/electrofelix))
- Fix release workflow [\#1157](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1157) ([electrofelix](https://github.com/electrofelix))
- \#1155 support setting ovs interface id [\#1156](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1156) ([abbbi](https://github.com/abbbi))
- fix typo [\#1154](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1154) ([rwrr](https://github.com/rwrr))
- Limit docker image push [\#1152](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1152) ([electrofelix](https://github.com/electrofelix))
- Support separate storage pools for additional disks [\#1130](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1130) ([abbbi](https://github.com/abbbi))
- Support the newly-introduced --no-tty Vagrant's option [\#1120](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1120) ([mrc0mmand](https://github.com/mrc0mmand))
- Add forward mode 'open' to README [\#1118](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1118) ([IPv4v6](https://github.com/IPv4v6))
- With additional notes for Fedora [\#1107](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1107) ([buckaroogeek](https://github.com/buckaroogeek))
  \* *This Changelog was automatically generated by [github_changelog_generator](https://github.com/github-changelog-generator/github-changelog-generator)*
* Thu Oct 22 2020 Dan Čermák <dcermak@suse.com>
  New upstream release 0.2.1
  [#]# [0.2.1](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.2.1) (2020-10-03)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.2.0...0.2.1)
  * *Closed issues:**
- Erubis dependency #1142
  [#]# [0.2.0](https://github.com/vagrant-libvirt/vagrant-libvirt/tree/0.2.0) (2020-10-03)
  [Full Changelog](https://github.com/vagrant-libvirt/vagrant-libvirt/compare/0.1.2...0.2.0)
  * *Closed issues:**
- First time using - vagrant up fails with network related errors [\#1146](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1146)
- Waiting for domain to get an IP address [\#1145](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1145)
- CentOS 8   fail to install libvirt Failed to build gem native extension [\#1135](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1135)
- `\<module:Util\>': uninitialized constant VagrantPlugins::ProviderLibvirt::Util::ErbTemplate \(NameError\) [\#1131](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1131)
- vagrant asking for VBoxManage binary [\#1125](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1125)
- after upgrading vagrant to 2.2.9 \(from 2.2.7\) a vagrant up destroys the domain on error [\#1122](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1122)
- Failure to detect second machine instance using Vagrant CLI [\#1121](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1121)
- Help/Feature-Request: Host-only management network [\#1117](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1117)
- libvirt plugin install FAILs to find existing "package configuration for libvirt is not found" [\#1104](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1104)
- Fedora box download is not available  [\#1070](https://github.com/vagrant-libvirt/vagrant-libvirt/issues/1070)
  * *Merged pull requests:**
- Support release notes generation [\#1150](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1150) ([electrofelix](https://github.com/electrofelix))
- Add docker image for vagrant-libvirt [\#1149](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1149) ([electrofelix](https://github.com/electrofelix))
- Use Vagrant::Util::TemplateRenderer instead of Erubis. [\#1144](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1144) ([voxik](https://github.com/voxik))
- config: allow for setting URI from environment [\#1141](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1141) ([electrofelix](https://github.com/electrofelix))
- Limit CI jobs to a subset of combinations [\#1140](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1140) ([electrofelix](https://github.com/electrofelix))
- Add @uri config tests and minor refactor [\#1139](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1139) ([electrofelix](https://github.com/electrofelix))
- Update test syntax to remove stubs [\#1138](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1138) ([electrofelix](https://github.com/electrofelix))
- let the user set the domain title and description [\#1137](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1137) ([rgl](https://github.com/rgl))
- remove redundant setting of default volume/backingStore mode [\#1134](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1134) ([eighthave](https://github.com/eighthave))
- Add WWN support [\#1123](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1123) ([cvoltz](https://github.com/cvoltz))
- update examples to use fedora/32-cloud-base [\#1119](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1119) ([timhughes](https://github.com/timhughes))
- add snapshot\_pool\_name to README [\#1114](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1114) ([abbbi](https://github.com/abbbi))
- action/forward\_ports.rb: Fix SSH tunnel spawning and PID tracking [\#1037](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1037) ([zakame](https://github.com/zakame))
- Add public\_address provider capability [\#1036](https://github.com/vagrant-libvirt/vagrant-libvirt/pull/1036) ([zakame](https://github.com/zakame))
* Thu Sep 10 2020 Dan Čermák <dcermak@suse.com>
- Require qemu-x86/arm on the x86/arm respectively
- Add constraint on the childprocess version to fix "have choice" errors
* Tue Sep  8 2020 Dan Čermák <dcermak@suse.com>
- Switch back to the default Ruby for Tumbleweed
  * Recommend guestfs-tools for virt-sysprep (needed for vagrant package with
    vagrant-libvirt)
* Thu Sep  3 2020 Dan Čermák <dcermak@suse.com>
- Change dependency on qemu-kvm from Recommends to Requires
* Wed Aug 19 2020 Dan Čermák <dcermak@suse.com>
- New upstream release 0.1.2
  Drop patches (integrated upstream):
  * 0001-Revert-back-to-development-versiongemspec-file..patch
  * 0002-Use-the-same-version-of-Nokogiri-as-Vagrant.patch
  * 0003-Update-fog-core-to-latest-version.patch
  v0.1.2:
  * #1110 prune_nfs_exports.rb:18:in call': undefined method info' for nil:NilClass
  v0.1.1
  * Merge pull request #1111 from AmedeeBulle/issue-1110
  v0.1.0
  * Improve Fedora installation procedure (#1101)
* Tue May 12 2020 Dan Čermák <dcermak@suse.com>
- Switch to Ruby 2.6 for Tumbleweed
* Mon Mar 23 2020 Dan Čermák <dcermak@suse.com>
- Add missing requires on nokogiri
* Wed Nov 13 2019 Dan Čermák <dcermak@suse.com>
- depend on nokogiri 1.10.x instead of hardcoding 1.10.4
* Fri Aug 23 2019 Dan Čermák <dcermak@suse.com>
- Bump nokogiri BuildRequires version
* Sun Jul  7 2019 Jan Engelhardt <jengelh@inai.de>
- Grammar fixes to the description.
* Tue Jul  2 2019 Dan Čermák <dcermak@suse.com>
- Remove obsolete gem2rpm.yml
* Tue Apr  2 2019 Dan Čermák <dcermak@suse.com>
- Restructure package into a system-wide vagrant plugin
* Mon Jan  7 2019 Dan Čermák <dcermak@suse.com>
- small fixes:
  * enhance %%description
  * remove github dotfiles from package
  * install vargrant-libvirt.json
  * remove /usr/bin/env bash from create_box.sh
* Thu Nov 22 2018 Stephan Kulow <coolo@suse.com>
- updated to version 0.0.45
  no changelog found
* Tue Feb 27 2018 factory-auto@kulow.org
- updated to version 0.0.43
  CHANGELOG.md removed upstream
* Thu Aug  3 2017 coolo@suse.com
- updated to version 0.0.40
  see installed CHANGELOG.md
* Tue May 16 2017 opensuse_buildservice@ojkastl.de
- added vagrant-libvirt.json
